"""
Simple KVDB 基本使用示例
"""

from simple_kvdb import KVDB

def main():
    """基本使用示例"""
    print("=== Simple KVDB 基本使用示例 ===\n")
    
    # 创建数据库实例
    db = KVDB("example_db.json")
    
    # 1. 基本操作
    print("1. 基本操作:")
    db.set("user:1", {"name": "张三", "age": 25, "city": "北京"})
    db.set("user:2", {"name": "李四", "age": 30, "city": "上海"})
    
    user1 = db.get("user:1")
    print(f"   用户1: {user1}")
    
    # 2. 检查键是否存在
    print("\n2. 检查键是否存在:")
    if db.exists("user:1"):
        print("   用户1存在")
    else:
        print("   用户1不存在")
    
    # 3. 获取所有键
    print("\n3. 所有键:")
    keys = db.keys()
    print(f"   键列表: {keys}")
    
    # 4. 批量操作
    print("\n4. 批量操作:")
    db.set_many({
        "config:theme": "dark",
        "config:language": "zh-CN",
        "stats:visits": 1000
    })
    
    # 批量获取
    config_values = db.get_many(["config:theme", "config:language"])
    print(f"   配置值: {config_values}")
    
    # 5. 原子操作
    print("\n5. 原子操作:")
    db.atomic_update("stats:visits", lambda x: (x or 0) + 1)
    visits = db.get("stats:visits")
    print(f"   访问次数: {visits}")
    
    # 6. 数据库大小
    print(f"\n6. 数据库大小: {db.size()} 个键值对")
    
    # 7. 删除操作
    print("\n7. 删除操作:")
    db.delete("user:2")
    print(f"   删除用户2后的大小: {db.size()}")
    
    # 8. 使用字典接口
    print("\n8. 字典接口:")
    db["dict_key"] = "dict_value"
    print(f"   通过字典接口设置的值: {db['dict_key']}")
    
    # 9. 导出数据
    print("\n9. 导出数据:")
    exported_data = db.export()
    print(f"   导出的数据: {exported_data}")
    
    # 10. 上下文管理器
    print("\n10. 上下文管理器:")
    with KVDB("temp_db.json") as temp_db:
        temp_db.set("temp_key", "temp_value")
        print("   在上下文管理器中设置数据")
    
    # 验证数据已保存
    temp_db = KVDB("temp_db.json")
    print(f"   上下文管理器外的数据: {temp_db.get('temp_key')}")
    
    print("\n=== 示例完成 ===")

if __name__ == "__main__":
    main() 